! 20 Sep 90
!
! wp50.cmd      - This file was created for use with WordPerfect 5.0 for
!                 Unix/Xenix systems.  This file performs the following
!                 keyboard mappings on TERM:
!
!                    * Map TERM's function keys to ALT-Number keys.
!                    * Map Ctrl-Shift-Fkeys to Alt-Fkeys.
!                    * Assigns new sequences to a number of keys and
!                      Ctrl-key combinations.
!
!                 This file is loaded by starting TERM from DOS using
!                 the name of this file as a parameter.  For example
!                 enter
!
!                    term wp50
!
!                 from the DOS prompt to start TERM.  The menu is accessed
!                 by pressing Alt-1.
!
!                 Under UNIX/Xenix set: WPTERM=TERM610 
!                                   or  WPTERM=TERM
!                                  and  TERM=ansi or TERM=ansic 
!

setkey	alt1	menu		!map TERM's function keys to Alt-numbers
setkey	alt2	help
setkey	alt3	gold
setkey	alt4	shell
setkey	alt5	capture
setkey	alt6	print
setkey	alt7	cmd
setkey	alt8	break
setkey	alt9	compose

setkey	kp-	"\E[-"		!keypad -
setkey	kp+	"\E[+"		!keypad +
setkey	clear	"\E[E"		!Ctrl-Home
setkey	scrup	"\E[J"		!Ctrl-PgUp
setkey	scrdn	"\E[K"		!Ctrl-PgDn
setkey	clreos	"\E[0"		!Ctrl-End
setkey	delline	"\E[1"		!Ctrl-LeftArrow
setkey	insline	"\E[2"		!Ctrl-RightArrow
setkey	c-enter	"\E[3"		!Ctrl-Enter
setkey	c-bs	"\E[4"		!Ctrl-BackSpace
setkey	backtab	"\E[5"		!Shift-Tab
setkey	"^H"	"\E{h"		!Ctrl-H
setkey	"^Q"	"\E{q"		!Ctrl-Q
setkey	"^S"	"\E{s"		!Ctrl-S

setkey	af1	"\E[w"		!Map Ctrl-Shift-Fkeys to Alt-Fkeys
setkey	af2	"\E[x"
setkey	af3	"\E[y"
setkey	af4	"\E[z"
setkey	af5	"\E[\\@"
setkey	af6	"\E[["
setkey	af7	"\E[\\\\"
setkey	af8	"\E[]"
setkey	af9	"\E[\\\^"
setkey	af10	"\E[_"

setkey	alta	"\E|a"		!Assign sequences to Alt-A through Alt-Z
setkey	altb	"\E|b"
setkey	altc	"\E|c"
setkey	altd	"\E|d"
setkey	alte	"\E|e"
setkey	altf	"\E|f"
setkey	altg	"\E|g"
setkey	alth	"\E|h"
setkey	alti	"\E|i"
setkey	altj	"\E|j"
setkey	altk	"\E|k"
setkey	altl	"\E|l"
setkey	altm	"\E|m"
setkey	altn	"\E|n"
setkey	alto	"\E|o"
setkey	altp	"\E|p"
setkey	altq	"\E|q"
setkey	altr	"\E|r"
setkey	alts	"\E|s"
setkey	altt	"\E|t"
setkey	altu	"\E|u"
setkey	altv	"\E|v"
setkey	altw	"\E|w"
setkey	altx	"\E|x"
setkey	alty	"\E|y"
setkey	altz	"\E|z"

display "Function keys remapped to ALT-Number keys."
display "\^E remapped to Alt-7, \^B to Alt-8."
