! 16 Jun 90
! Wang 2110A Emulation Script
!
! The 2110A is almost a VT220, with the exceptions taken care
! of by this script.
!
!				  2110A		PC		Term
!				  Key		Key		KeyName
!				  --------	--------	--------
emulate vt220-7
setkey home	"\E[H"		! home		home		home
				! exec		cf6		f16 (vt220 DO)
setkey kpr	"\E[29~"	! exec		kpenter		kpenter
setkey kp-	"\E[37~"	! cancel	kp-		kp-
setkey c-kp-	"\E[38~"	! ctrl-cancel	c-kp-		c-ckp-
				! insert	ins		ins
				! delete	del		del
				! prev		page up		pgup
				! next		page dn		pgdn
				! help		cf5		f15 (vt220 HELP)
				! f1-f4		f1-f4		f1-f4
setkey f5 	"\E[15~"	! f5		f5		f5
				! f6-f10	f6-f10		f6-f10
				! f11-f14	cf1-cf4		cf1-cf4
setkey cf5	"\E[35~"	! f15		cf5		cf5
setkey sf1	"\E[31~"	! sf1		sf1		sf1 (vt220 F17)
setkey sf2	"\E[32~"	! sf2		sf2		sf2 (vt220 F18)
setkey sf3	"\E[33~"	! sf3		sf3		sf3 (vt220 F19)
setkey sf4	"\E[34~"	! sf4		sf4		sf4 (vt220 F20)
				! sf5-sf8	sf5-sf8		sf5-sf8
setkey sf9	"\E[1~"		! sf9		sf9		sf9 (vt220 FIND)
				! sf10		sf10		sf10
				! sf11-sf15	csf1-csf5	csf1-csf5
setkey csf6	"\E[4~"		! sf16		csf6		csf6 (vt220 SEL)
