mode half
setkey '\x07'	'<BS>'
setkey '\x7f'	'<DEL>'			! the "real" delete

setkey f1	'f1'
setkey f2	'f2'
setkey f3	'f3'
setkey f4	'f4'
setkey f5	'f5'
setkey f6	'f6'
setkey f7	'f7'
setkey f8	'f8'
setkey f9	'f9'
setkey f10	'f10'
setkey f11	'f11'
setkey f12	'f12'
setkey f13	'f13'
setkey f14	'f14'
setkey f15	'f15'
setkey f16	'f16'

setkey up	'up'
setkey down	'down'
setkey right	'right'
setkey left	'left'
setkey c-up	'c-up'
setkey c-down	'c-down'
setkey c-right	'c-right'
setkey c-left	'c-left'

setkey ins	'ins'
setkey del	'del'			! the "other" delete
setkey home	'home'
setkey end	'end'
setkey pgdn	'pgdn'
setkey pgup	'pgup'
setkey c-ins	'c-ins'
setkey c-del	'c-del'
setkey c-home	'c-home'
setkey c-end	'c-end'
setkey c-pgup	'c-pgup'
setkey c-pgdn	'c-pgdn'

setkey kp0	'kp0'
setkey kp1	'kp1'
setkey kp2	'kp2'
setkey kp3	'kp3'
setkey kp4	'kp4'
setkey kp5	'kp5'
setkey kp6	'kp6'
setkey kp7	'kp7'
setkey kp8	'kp8'
setkey kp9	'kp9'
setkey kp.	'kp.'
setkey kp-	'kp-'
setkey kp+	'kp+'
setkey kpr	'kpr'
setkey kp/	'kp/'
setkey kp*	'kp*'
setkey kp,	'kp,'
setkey c-kp-	'c-kp-'
setkey c-kp+	'c-kp+'
setkey c-kpr	'c-kpr'
setkey c-kp/	'c-kp/'
setkey five	'five'
setkey c-five	'c-five'

setkey print	'print'
setkey numlock	'numlock'
setkey scrlock	'scrlock'

setkey bs	'bs'
setkey s-tab	's-tab'
setkey c-bs	'c-bs'
setkey c-enter	'c-enter'
setkey c-esc	'c-esc'
setkey c-tab	'c-tab'

setkey sf1	'sf1'
setkey sf2	'sf2'
setkey sf3	'sf3'
setkey sf4	'sf4'
setkey sf5	'sf5'
setkey sf6	'sf6'
setkey sf7	'sf7'
setkey sf8	'sf8'
setkey sf9	'sf9'
setkey sf10	'sf10'
setkey sf11	'sf11'
setkey sf12	'sf12'
setkey sf13	'sf13'
setkey sf14	'sf14'
setkey sf15	'sf15'
setkey sf16	'sf16'
setkey cf1	'cf1'
setkey cf2	'cf2'
setkey cf3	'cf3'
setkey cf4	'cf4'
setkey cf5	'cf5'
setkey cf6	'cf6'
setkey cf7	'cf7'
setkey cf8	'cf8'
setkey cf9	'cf9'
setkey cf10	'cf10'
setkey cf12	'cf12'
setkey cf13	'cf13'
setkey cf14	'cf14'
setkey cf15	'cf15'
setkey cf16	'cf16'
setkey af1	'af1'
setkey af2	'af2'
setkey af3	'af3'
setkey af4	'af4'
setkey af5	'af5'
setkey af6	'af6'
setkey af7	'af7'
setkey af8	'af8'
setkey af9	'af9'
setkey af10	'af10'
setkey af11	'af11'
setkey af12	'af12'
setkey af13	'af13'
setkey af14	'af14'
setkey af15	'af15'
setkey af16	'af16'
setkey csf1	'csf1'
setkey csf2	'csf2'
setkey csf3	'csf3'
setkey csf4	'csf4'
setkey csf5	'csf5'
setkey csf6	'csf6'
setkey csf7	'csf7'
setkey csf8	'csf8'
setkey csf9	'csf9'
setkey csf10	'csf10'
setkey csf11	'csf11'
setkey csf12	'csf12'
setkey csf13	'csf13'
setkey csf14	'csf14'
setkey csf15	'csf15'
setkey csf16	'csf16'
setkey alta	'alta'
setkey altb	'altb'
setkey altc	'altc'
setkey altd	'altd'
setkey alte	'alte'
setkey altf	'altf'
setkey altg	'altg'
setkey alth	'alth'
setkey alti	'alti'
setkey altj	'altj'
setkey altk	'altk'
setkey altl	'altl'
setkey altm	'altm'
setkey altn	'altn'
setkey alto	'alto'
setkey altp	'altp'
setkey altq	'altq'
setkey alts	'alts'
setkey altt	'altt'
setkey altu	'altu'
setkey altv	'altv'
setkey altw	'altw'
setkey altx	'altx'
setkey alty	'alty'
setkey altz	'altz'
setkey alt1	'alt1'
setkey alt2	'alt2'
setkey alt3	'alt3'
setkey alt4	'alt4'
setkey alt5	'alt5'
setkey alt6	'alt6'
setkey alt7	'alt7'
setkey alt8	'alt8'
setkey alt9	'alt9'
setkey alt0	'alt0'
setkey alt-	'alt-'
setkey alt=	'alt='
